@@ -6,6 +6,7 @@
 #include <QGraphicsPixmapItem>
 #include <QtWidgets/QMessageBox>
 #include <utils/gui.h>
+#include <mainwindow.h>
 #include "orphanedimagesdialog.h"
 #include "ui_orphanedimagesdialog.h"
 
@@ -33,17 +34,10 @@ OrphanedImagesDialog::OrphanedImagesDialog(QWidget *parent) :
     ui->progressBar->show();
 
     Q_FOREACH(Note note, noteList) {
-            QString text = note.getNoteText();
-
-            // match image links like ![media-qV920](file://media/608766373.gif)
-            QRegularExpression re(
-                    "!\\[.*?\\]\\(file:\\/\\/media/(.+?)\\)");
-            QRegularExpressionMatchIterator i = re.globalMatch(text);
+            QStringList mediaFileList = note.getMediaFileList();
 
             // remove all found images from the orphaned files list
-            while (i.hasNext()) {
-                QRegularExpressionMatch match = i.next();
-                QString fileName = match.captured(1);
+            Q_FOREACH(QString fileName, mediaFileList) {
                 orphanedFiles.removeAll(fileName);
             }
 
@@ -64,6 +58,13 @@ OrphanedImagesDialog::OrphanedImagesDialog(QWidget *parent) :
 
             ui->fileTreeWidget->addTopLevelItem(item);
         }
+
+    // jump to the first item
+    if (orphanedFiles.count() > 0) {
+        QKeyEvent *event = new QKeyEvent(QEvent::KeyPress, Qt::Key_Home,
+                                         Qt::NoModifier);
+        QApplication::postEvent(ui->fileTreeWidget, event);
+    }
 }
 
 OrphanedImagesDialog::~OrphanedImagesDialog() {
@@ -160,3 +161,33 @@ bool OrphanedImagesDialog::eventFilter(QObject *obj, QEvent *event) {
 
     return MasterDialog::eventFilter(obj, event);
 }
+
+void OrphanedImagesDialog::on_insertButton_clicked() {
+#ifndef INTEGRATION_TESTS
+    MainWindow *mainWindow = MainWindow::instance();
+    if (mainWindow == Q_NULLPTR) {
+        return;
+    }
+#else
+    return;
+#endif
+
+    int selectedItemsCount = ui->fileTreeWidget->selectedItems().count();
+
+    if (selectedItemsCount == 0) {
+        return;
+    }
+
+    QOwnNotesMarkdownTextEdit *textEdit = mainWindow->activeNoteTextEdit();
+
+    // insert all selected images
+    Q_FOREACH(QTreeWidgetItem *item, ui->fileTreeWidget->selectedItems()) {
+            QString filePath = getFilePath(item);
+            QFileInfo fileInfo(filePath);
+            QString mediaUrlString = "file://media/" + fileInfo.fileName();
+            QString imageLink = "![" + fileInfo.baseName() + "](" +
+                             mediaUrlString + ")\n";
+            textEdit->insertPlainText(imageLink);
+            delete item;
+    }
+}
