@@ -14,6 +14,7 @@
 #include <services/owncloudservice.h>
 #include <QCheckBox>
 #include <QtCore/QSettings>
+#include <libraries/qkeysequencewidget/qkeysequencewidget/src/qkeysequencewidget.h>
 #include "masterdialog.h"
 
 namespace Ui {
@@ -50,7 +51,10 @@ public:
         DebugOptionPage,
         EditorPage,
         GitPage,
-        PanelsPage
+        PanelsPage,
+        LocalTrashPage,
+        LayoutPage,
+        WebCompanionPage
     };
 
     explicit SettingsDialog(int page = 0,
@@ -228,6 +232,30 @@ private slots:
 
     void on_resetMessageBoxesButton_clicked();
 
+    void on_markdownHighlightingCheckBox_toggled(bool checked);
+
+    void on_localTrashEnabledCheckBox_toggled(bool checked);
+
+    void on_localTrashClearCheckBox_toggled(bool checked);
+
+    void keySequenceEvent(QString objectName);
+
+    void on_exportSettingsButton_clicked();
+
+    void on_importSettingsButton_clicked();
+
+    void on_issueAssistantPushButton_clicked();
+
+    void on_ignoreNoteSubFoldersResetButton_clicked();
+
+    void on_interfaceFontSizeSpinBox_valueChanged(int arg1);
+
+    void on_overrideInterfaceFontSizeGroupBox_toggled(bool arg1);
+
+    void on_webSocketServerServicePortResetButton_clicked();
+
+    void on_enableSocketServerCheckBox_toggled();
+
 private:
 
     Ui::SettingsDialog *ui;
@@ -258,8 +286,6 @@ private:
 
     void outputSettings();
 
-    QString prepareDebugInformationLine(QString headline, QString data);
-
     static void selectListWidgetValue(QListWidget *listWidget, QString value);
 
     static bool listWidgetValueExists(QListWidget* listWidget, QString value);
@@ -329,6 +355,10 @@ private:
     void loadInterfaceStyleComboBox() const;
 
     void initSearchEngineComboBox() const;
+
+    QKeySequenceWidget *findKeySequenceWidget(QString objectName);
+
+    void storeOwncloudDebugData() const;
 };
 
 #endif // SETTINGSDIALOG_H
