@@ -1,6 +1,8 @@
 #include "notehistory.h"
 #include <QScrollBar>
+#include <QSettings>
 #include <QDebug>
+#include <entities/notefolder.h>
 
 /*
  * NoteHistoryItem implementation
@@ -277,9 +279,144 @@ void NoteHistory::clear() {
     noteHistory->clear();
     currentIndex = 0;
 }
+/**
+ * Stores the note history for the current note folder
+ */
+void NoteHistory::storeForCurrentNoteFolder() {
+    QSettings settings;
+    int currentNoteFolderId = NoteFolder::currentNoteFolderId();
+    QVariantList noteHistoryVariantItems;
+    const QList<NoteHistoryItem> &noteHistoryItems = getNoteHistoryItems();
+    const int noteHistoryItemCount = noteHistoryItems.count();
+
+    // we only want to store the last 200 note history items
+    const int maxCount = std::min(noteHistoryItemCount, 200);
+
+    if (maxCount == 0) {
+        return;
+    }
+
+    int newCurrentIndex = 0;
+    int count = 0;
+
+    // store the last
+    for (int i = noteHistoryItemCount - maxCount; i < noteHistoryItemCount; i++) {
+        noteHistoryVariantItems.append(QVariant::fromValue(
+                noteHistoryItems.at(i)));
+
+        if (i == currentIndex) {
+            newCurrentIndex = count;
+        }
+
+        count++;
+    }
+
+    // store the note history settings of the old note folder
+    settings.setValue("NoteHistory-" + QString::number(currentNoteFolderId),
+                      noteHistoryVariantItems);
+
+    settings.setValue("NoteHistoryCurrentIndex-" + QString::number(
+            currentNoteFolderId), newCurrentIndex);
+}
+
+/**
+ * Restores the note history for the current note folder
+ */
+void NoteHistory::restoreForCurrentNoteFolder() {
+    QSettings settings;
+    int currentNoteFolderId = NoteFolder::currentNoteFolderId();
+    clear();
+
+    // restore the note history of the new note folder
+    QVariantList noteHistoryVariantItems = settings.value(
+            "NoteHistory-" + QString::number(currentNoteFolderId)).toList();
+
+    if (noteHistoryVariantItems.count() == 0) {
+        return;
+    }
+
+    int maxIndex = -1;
+    Q_FOREACH(QVariant item, noteHistoryVariantItems) {
+            // check if the NoteHistoryItem could be de-serialized
+            if (item.isValid()) {
+                NoteHistoryItem noteHistoryItem =
+                        item.value<NoteHistoryItem>();
+                addNoteHistoryItem(noteHistoryItem);
+                maxIndex++;
+            }
+        }
+
+    int newCurrentIndex = settings.value("NoteHistoryCurrentIndex-" +
+                                      QString::number(currentNoteFolderId)).toInt();
+
+    if (newCurrentIndex > 0 && newCurrentIndex <= maxIndex) {
+        currentIndex = newCurrentIndex;
+    }
+}
 
 QDebug operator<<(QDebug dbg, const NoteHistory &history) {
     dbg.nospace() << "NoteHistory: <index>" << history.currentIndex <<
     " <noteHistorySize>" << history.noteHistory->size();
     return dbg.space();
 }
+
+/**
+ * Returns a list of NoteHistoryItems of the note history
+ *
+ * @return
+ */
+QList<NoteHistoryItem> NoteHistory::getNoteHistoryItems() const {
+    QList<NoteHistoryItem> items;
+
+    for (int i = 0; i < noteHistory->count(); i++) {
+        NoteHistoryItem item = noteHistory->at(i);
+
+        items.append(item);
+    }
+
+    return items;
+}
+
+/**
+ * Appends a NoteHistoryItem to the note history
+ *
+ * @param item
+ */
+void NoteHistory::addNoteHistoryItem(NoteHistoryItem item) {
+    noteHistory->append(item);
+}
+
+/**
+ * Stream operator for storing the class to QSettings
+ * Note: This method doesn't seem to get called when serializing for
+ *       writing to the settings
+ *
+ * @param out
+ * @param history
+ * @return
+ */
+QDataStream &operator<<(QDataStream &out, const NoteHistory &history) {
+    Q_FOREACH(NoteHistoryItem item, history.getNoteHistoryItems()) {
+        out << item;
+    }
+
+    return out;
+}
+
+/**
+ * Stream operator for loading the class from QSettings
+ *
+ * @param in
+ * @param history
+ * @return
+ */
+QDataStream &operator>>(QDataStream &in, NoteHistory &history) {
+    NoteHistoryItem item;
+
+    while (!in.atEnd()) {
+        in >> item;
+        history.addNoteHistoryItem(item);
+    }
+
+    return in;
+}
