@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2017 Patrizio Bekerle -- http://www.bekerle.com
+ * Copyright (c) 2014-2019 Patrizio Bekerle -- http://www.bekerle.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,11 @@
  */
 
 #include <QTimer>
+#include <QDebug>
 #include "markdownhighlighter.h"
+#include <QRegularExpression>
+#include <QRegularExpressionMatch>
+#include <QRegularExpressionMatchIterator>
 
 
 /**
@@ -26,8 +30,10 @@
  * @param parent
  * @return
  */
-MarkdownHighlighter::MarkdownHighlighter(QTextDocument *parent)
+MarkdownHighlighter::MarkdownHighlighter(
+        QTextDocument *parent, HighlightingOptions highlightingOptions)
         : QSyntaxHighlighter(parent) {
+    _highlightingOptions = highlightingOptions;
     _timer = new QTimer(this);
     QObject::connect(_timer, SIGNAL(timeout()),
                      this, SLOT(timerTick()));
@@ -44,6 +50,8 @@ MarkdownHighlighter::MarkdownHighlighter(QTextDocument *parent)
  * Does jobs every second
  */
 void MarkdownHighlighter::timerTick() {
+    // qDebug() << "timerTick: " << this << ", " << this->parent()->parent()->parent()->objectName();
+
     // re-highlight all dirty blocks
     reHighlightDirtyBlocks();
 
@@ -114,7 +122,10 @@ void MarkdownHighlighter::initHighlightingRules() {
 
     // highlight block quotes
     rule = HighlightingRule();
-    rule.pattern = QRegularExpression("^\\s*(>\\s*)+");
+    rule.pattern = QRegularExpression(
+            _highlightingOptions.testFlag(
+                    HighlightingOption::FullyHighlightedBlockQuote) ?
+                    "^\\s*(>\\s*.+)" : "^\\s*(>\\s*)+");
     rule.state = HighlighterState::BlockQuote;
     _highlightingRulesPre.append(rule);
 
@@ -267,14 +278,17 @@ void MarkdownHighlighter::initTextFormats(int defaultFontSize) {
     format.setFontWeight(QFont::Bold);
     format.setFontPointSize(defaultFontSize * 1.6);
     _formats[H1] = format;
-    format.setFontPointSize(defaultFontSize * 1.3);
+    format.setFontPointSize(defaultFontSize * 1.5);
     _formats[H2] = format;
-    format.setFontPointSize(defaultFontSize * 1.1);
+    format.setFontPointSize(defaultFontSize * 1.4);
     _formats[H3] = format;
-    format.setFontPointSize(defaultFontSize);
+    format.setFontPointSize(defaultFontSize * 1.3);
     _formats[H4] = format;
+    format.setFontPointSize(defaultFontSize * 1.2);
     _formats[H5] = format;
+    format.setFontPointSize(defaultFontSize * 1.1);
     _formats[H6] = format;
+    format.setFontPointSize(defaultFontSize);
 
     // set character format for horizontal rulers
     format = QTextCharFormat();
@@ -393,8 +407,8 @@ void MarkdownHighlighter::highlightMarkdown(QString text) {
  * @param text
  */
 void MarkdownHighlighter::highlightHeadline(QString text) {
-    QRegularExpression re("^(#+)\\s+(.+?)$");
-    QRegularExpressionMatch match = re.match(text);
+    QRegularExpression regex("^(#+)\\s+(.+?)$");
+    QRegularExpressionMatch match = regex.match(text);
     QTextCharFormat &maskedFormat = _formats[HighlighterState::MaskedSyntax];
 
     // check for headline blocks with # in front of them
@@ -555,8 +569,8 @@ void MarkdownHighlighter::setCurrentBlockMargin(
  * @param text
  */
 void MarkdownHighlighter::highlightCodeBlock(QString text) {
-    QRegularExpression re("^```\\w*?$");
-    QRegularExpressionMatch match = re.match(text);
+    QRegularExpression regex("^```\\w*?$");
+    QRegularExpressionMatch match = regex.match(text);
 
     if (match.hasMatch()) {
         setCurrentBlockState(
@@ -582,7 +596,7 @@ void MarkdownHighlighter::highlightCodeBlock(QString text) {
  */
 void MarkdownHighlighter::highlightCommentBlock(QString text) {
     bool highlight = false;
-    text.trimmed();
+    text = text.trimmed();
     QString startText = "<!--";
     QString endText = "-->";
 
@@ -624,20 +638,20 @@ void MarkdownHighlighter::highlightAdditionalRules(
             }
 
             QRegularExpression expression(rule.pattern);
-            QRegularExpressionMatchIterator i = expression.globalMatch(text);
+            QRegularExpressionMatchIterator iterator = expression.globalMatch(text);
             int capturingGroup = rule.capturingGroup;
             int maskedGroup = rule.maskedGroup;
             QTextCharFormat &format = _formats[rule.state];
 
             // store the current block state if useStateAsCurrentBlockState
             // is set
-            if (i.hasNext() && rule.useStateAsCurrentBlockState) {
+            if (iterator.hasNext() && rule.useStateAsCurrentBlockState) {
                 setCurrentBlockState(rule.state);
             }
 
             // find and format all occurrences
-            while (i.hasNext()) {
-                QRegularExpressionMatch match = i.next();
+            while (iterator.hasNext()) {
+                QRegularExpressionMatch match = iterator.next();
 
                 // if there is a capturingGroup set then first highlight
                 // everything as MaskedSyntax and highlight capturingGroup
@@ -658,3 +672,7 @@ void MarkdownHighlighter::highlightAdditionalRules(
             }
         }
 }
+
+void MarkdownHighlighter::setHighlightingOptions(HighlightingOptions options) {
+    _highlightingOptions = options;
+}
