@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2017 Patrizio Bekerle -- http://www.bekerle.com
+ * Copyright (c) 2014-2019 Patrizio Bekerle -- http://www.bekerle.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ public:
 
     Q_DECLARE_FLAGS(AutoTextOptions, AutoTextOption)
 
-    explicit QMarkdownTextEdit(QWidget *parent = 0);
+    explicit QMarkdownTextEdit(QWidget *parent = 0, bool initHighlighter = true);
     MarkdownHighlighter *highlighter();
     QPlainTextEditSearchWidget *searchWidget();
     void setIgnoredClickUrlSchemata(QStringList ignoredUrlSchemata);
@@ -48,6 +48,7 @@ public:
     void setHighlightingEnabled(bool enabled);
     static bool isValidUrl(QString urlString);
     void resetMouseCursor() const;
+    void setReadOnly(bool ro);
 
 public slots:
     void duplicateText();
@@ -77,6 +78,7 @@ protected:
                               QString closingCharacter = "");
     bool bracketClosingCheck(QString openingCharacter,
                              QString closingCharacter);
+    bool quotationMarkCheck(QString quotationCharacter);
     void focusOutEvent(QFocusEvent *event);
     void paintEvent(QPaintEvent *e);
 
