@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2017 Patrizio Bekerle -- http://www.bekerle.com
+ * Copyright (c) 2014-2019 Patrizio Bekerle -- http://www.bekerle.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -157,29 +157,29 @@ bool QPlainTextEditSearchWidget::doReplace(bool forAll) {
         return false;
     }
 
-    QTextCursor c = _textEdit->textCursor();
+    QTextCursor cursor = _textEdit->textCursor();
 
-    if (!forAll && c.selectedText().isEmpty()) {
+    if (!forAll && cursor.selectedText().isEmpty()) {
         return false;
     }
 
     int searchMode = ui->modeComboBox->currentIndex();
     if (searchMode == RegularExpressionMode) {
-        QString text = c.selectedText();
+        QString text = cursor.selectedText();
         text.replace(QRegExp(ui->searchLineEdit->text()),
                              ui->replaceLineEdit->text());
-        c.insertText(text);
+        cursor.insertText(text);
     } else {
-        c.insertText(ui->replaceLineEdit->text());
+        cursor.insertText(ui->replaceLineEdit->text());
     }
 
     if (!forAll) {
-        int position = c.position();
+        int position = cursor.position();
 
         if (!doSearch(true)) {
             // restore the last cursor position if text wasn't found any more
-            c.setPosition(position);
-            _textEdit->setTextCursor(c);
+            cursor.setPosition(position);
+            _textEdit->setTextCursor(cursor);
         }
     }
 
