@@ -129,7 +129,7 @@ bool DatabaseService::createNoteFolderConnection() {
  * Creates or updates the note folder tables
  */
 bool DatabaseService::setupNoteFolderTables() {
-    QSqlDatabase dbDisk = QSqlDatabase::database("note_folder");
+    QSqlDatabase dbDisk = getNoteFolderDatabase();
     QSqlQuery queryDisk(dbDisk);
 
     queryDisk.exec("CREATE TABLE IF NOT EXISTS appData ("
@@ -246,7 +246,7 @@ bool DatabaseService::setupNoteFolderTables() {
     if (version < 12) {
         // create new tag table, because
         //     ALTER TABLE tag ADD updated DEFAULT CURRENT_TIMESTAMP
-        // is not supported by sqlite -- you cant add a column with
+        // is not supported by sqlite -- you can't add a column with
         // a non-constant default value. And if collate ... is used
         // on a column, it's also defaulted to indices on that column.
         queryDisk.exec("ALTER TABLE tag RENAME TO _tag");
@@ -281,14 +281,62 @@ bool DatabaseService::setupNoteFolderTables() {
         version = 12;
     }
 
+    if (version < 13) {
+        queryDisk.exec("CREATE TABLE IF NOT EXISTS trashItem ("
+                               "id INTEGER PRIMARY KEY,"
+                               "file_name VARCHAR(255),"
+                               "file_size INTEGER,"
+                               "note_sub_folder_path_data TEXT,"
+                               "created DATETIME DEFAULT current_timestamp)");
+
+        version = 13;
+    }
+
     if (version != oldVersion) {
         setAppData("database_version",
                    QString::number(version), "note_folder");
     }
 
+    closeDatabaseConnection(dbDisk, queryDisk);
+
     return true;
 }
 
+QSqlDatabase DatabaseService::getNoteFolderDatabase() {
+#ifdef Q_OS_WIN32
+    if (Utils::Misc::doAutomaticNoteFolderDatabaseClosing()) {
+        // open database if it was closed in closeDatabaseConnection
+        createNoteFolderConnection();
+    }
+#endif
+
+    QSqlDatabase db = QSqlDatabase::database("note_folder");
+//    db.transaction();
+    return db;
+}
+
+/**
+ * Closes a database connection if it was open
+ *
+ * @param db
+ */
+void DatabaseService::closeDatabaseConnection(QSqlDatabase &db,
+                                              QSqlQuery &query) {
+//    db.commit();
+#ifdef Q_OS_WIN32
+    if (Utils::Misc::doAutomaticNoteFolderDatabaseClosing()) {
+        query.clear();
+
+        if (db.isOpen()) {
+            db.close();
+        }
+    }
+#else
+    Q_UNUSED(db);
+    Q_UNUSED(query);
+#endif
+}
+
 bool DatabaseService::setupTables() {
     QSqlDatabase dbDisk = QSqlDatabase::database("disk");
     QSqlQuery queryDisk(dbDisk);
@@ -601,6 +649,32 @@ bool DatabaseService::setupTables() {
         version = 25;
     }
 
+    if (version < 26) {
+        // remove setting with wrong default value
+        settings.remove("localTrash/autoCleanupDays");
+
+        version = 26;
+    }
+
+    if (version < 27) {
+        // if the application was not started for the first time we want to
+        // disable that the note edit is the central widget
+        if (oldVersion != 0) {
+            settings.setValue("noteEditIsCentralWidget", false);
+        }
+
+        version = 27;
+    }
+
+    if (version < 28) {
+#ifndef Q_OS_MAC
+        // we only want one app instance on Windows and Linux by default
+        settings.setValue("allowOnlyOneAppInstance", true);
+#endif
+
+        version = 28;
+    }
+
     if (version != oldVersion) {
         setAppData("database_version", QString::number(version));
     }
