@@ -12,6 +12,7 @@
 #include <QHash>
 #include <QMap>
 #include <api/noteapi.h>
+#include <QMessageBox>
 
 #define PERSISTENT_VARIABLE_SETTINGS_PREFIX "PersistentScripting"
 
@@ -37,6 +38,8 @@ public:
     QVariant callNoteTaggingHook(Note note, QString action,
                                  QString tagName = "", QString newTagName = "");
     bool noteTaggingHookExists();
+    bool handleNoteNameHookExists();
+    bool methodExists(QString methodName);
     static bool validateScript(Script script, QString &errorMessage);
     Q_INVOKABLE bool startDetachedProcess(QString executablePath,
                                           QStringList parameters);
@@ -49,6 +52,8 @@ public:
     Q_INVOKABLE QString downloadUrlToString(QUrl url);
     Q_INVOKABLE QString downloadUrlToMedia(QUrl url,
                                            bool returnUrlOnly = false);
+    Q_INVOKABLE QString insertMediaFile(QString mediaFilePath,
+                                        bool returnUrlOnly = false);
     Q_INVOKABLE void registerCustomAction(
             QString identifier, QString menuText, QString buttonText = "",
             QString icon = "", bool useInNoteEditContextMenu = false,
@@ -58,6 +63,9 @@ public:
     Q_INVOKABLE QString clipboard(bool asHtml = false);
     Q_INVOKABLE void noteTextEditWrite(QString text);
     Q_INVOKABLE QString noteTextEditSelectedText();
+    Q_INVOKABLE void noteTextEditSelectAll();
+    Q_INVOKABLE QString noteTextEditCurrentWord(
+            bool withPreviousCharacters = false);
     Q_INVOKABLE void encryptionDisablePassword();
     Q_INVOKABLE bool platformIsLinux();
     Q_INVOKABLE bool platformIsOSX();
@@ -67,6 +75,7 @@ public:
     Q_INVOKABLE void reloadScriptingEngine();
     Q_INVOKABLE NoteApi* fetchNoteByFileName(QString fileName,
                                              int noteSubFolderId = -1);
+    Q_INVOKABLE NoteApi* fetchNoteById(int id);
     Q_INVOKABLE bool noteExistsByFileName(QString fileName,
                                           int ignoreNoteId = 0,
                                           int noteSubFolderId = -1);
@@ -75,9 +84,18 @@ public:
 
     Q_INVOKABLE void informationMessageBox(QString text, QString title = "");
 
+    Q_INVOKABLE int questionMessageBox(
+            QString text, QString title = "",
+            int buttons =
+            QMessageBox::StandardButtons(QMessageBox::Yes | QMessageBox::No),
+            int defaultButton = QMessageBox::NoButton);
+
     Q_INVOKABLE QString getOpenFileName(QString caption = "", QString dir = "",
                                         QString filter = "");
 
+    Q_INVOKABLE QString getSaveFileName(QString caption = "", QString dir = "",
+                                        QString filter = "");
+
     Q_INVOKABLE void registerLabel(QString identifier, QString text = "");
 
     Q_INVOKABLE void setLabelText(QString identifier, QString text);
@@ -98,6 +116,8 @@ public:
     QString callEncryptionHook(QString text, QString password,
                                bool decrypt = false);
     void callHandleNoteOpenedHook(Note *note);
+    QString callHandleNoteNameHook(Note *note);
+    void callHandleNoteDoubleClickedHook(Note *note);
     QList<QVariant> getSettingsVariables(int scriptId);
     Q_INVOKABLE QString toNativeDirSeparators(QString path);
     Q_INVOKABLE QString fromNativeDirSeparators(QString path);
@@ -109,7 +129,7 @@ public:
             const QStringList &items, int current = 0, bool editable = false);
 
     Q_INVOKABLE QString inputDialogGetText(
-            const QString &title, const QString &label, const QString &text);
+            const QString &title, const QString &label, const QString &text = "");
 
     Q_INVOKABLE void setPersistentVariable(const QString &key,
                                            const QVariant &value);
@@ -122,6 +142,19 @@ public:
 
     Q_INVOKABLE bool jumpToNoteSubFolder(const QString &noteSubFolderPath,
                                          QString separator = "/");
+    QStringList callAutocompletionHook();
+
+    Q_INVOKABLE QStringList searchTagsByName(QString name);
+
+    Q_INVOKABLE void regenerateNotePreview();
+
+    Q_INVOKABLE QList<int> selectedNotesIds();
+
+    Q_INVOKABLE bool writeToFile(const QString &filePath, const QString &data);
+
+    Q_INVOKABLE QList<int> fetchNoteIdsByNoteTextPart(QString text);
+
+    Q_INVOKABLE void triggerMenuAction(QString objectName, QString checked = "");
 
 private:
     QQmlEngine *_engine;
