@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2017 Patrizio Bekerle -- http://www.bekerle.com
+ * Copyright (c) 2014-2019 Patrizio Bekerle -- http://www.bekerle.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,8 +18,12 @@
 #include <QUrl>
 #include <QFile>
 #include <QByteArray>
+#include <QPrinter>
+#include <QDataStream>
 #include <QStringList>
 #include <QMap>
+#include <QSqlDatabase>
+#include "entities/bookmark.h"
 
 /*  Miscellaneous functions that can be useful */
 
@@ -71,5 +75,28 @@ namespace Utils {
         int getDefaultSearchEngineId();
         void presetDisableAutomaticUpdateDialog();
         QList<int> getSearchEnginesIds();
+        QDataStream &dataStreamWrite(QDataStream &os, const QPrinter &printer);
+        QDataStream &dataStreamRead(QDataStream &is, QPrinter &printer);
+        void storePrinterSettings(QPrinter *printer, QString settingsKey);
+        void loadPrinterSettings(QPrinter *printer, QString settingsKey);
+        bool isNoteEditingAllowed();
+        bool isSocketServerEnabled();
+        QString unescapeHtml(QString html);
+        QString htmlspecialchars(QString text);
+        void printInfo(QString text);
+        bool doAutomaticNoteFolderDatabaseClosing();
+        bool isNoteListPreview();
+        QString toHumanReadableByteSize(qint64 size);
+        QString prepareDebugInformationLine(
+            const QString &headline, QString data,
+            bool withGitHubLineBreaks = true,
+            QString typeText = "");
+        QString generateDebugInformation(bool withGitHubLineBreaks = true);
+        bool regExpInListMatches(QString text, QStringList regExpList);
+        QString importMediaFromBase64(QString &data, QString imageSuffix = "dat");
     }  // namespace Misc
 }  // namespace Utils
+
+
+QDataStream& operator<<(QDataStream &os, const QPrinter &printer);
+QDataStream& operator>>(QDataStream &is,  QPrinter &printer);
