@@ -3,6 +3,7 @@
 #include <QScrollBar>
 #include <QMenu>
 #include <QFile>
+#include <QKeyEvent>
 #include <QDebug>
 #include <utils/misc.h>
 #include "logwidget.h"
@@ -62,6 +63,9 @@ LogWidget::LogWidget(QWidget *parent) :
     connect(ui->statusCheckBox, SIGNAL(clicked()), this, SLOT(storeSettings()));
     connect(ui->scriptingCheckBox, SIGNAL(clicked()),
             this, SLOT(storeSettings()));
+
+    ui->logTextEdit->installEventFilter(this);
+    ui->buttonFrame->installEventFilter(this);
 #endif
 }
 
@@ -72,6 +76,17 @@ LogWidget::~LogWidget()
 #endif
 }
 
+/**
+ * Returns the text of the log widget
+ */
+QString LogWidget::getLogText() {
+#ifndef INTEGRATION_TESTS
+    return ui->logTextEdit->toPlainText();
+#else
+    return "";
+#endif
+}
+
 /**
  * Stores the settings of the dialog
  */
@@ -98,7 +113,14 @@ void LogWidget::storeSettings() const {
 /**
  * Adds a log entry
  */
-void LogWidget::log(LogType logType, QString text) {
+void LogWidget::log(LogWidget::LogType logType, QString text) {
+    // ignore "libpng sRGB profile" and "QXcbConnection: XCB error: 8" warnings
+    if (logType == WarningLogType &&
+        (text.contains("libpng warning: iCCP: known incorrect sRGB profile") ||
+         text.contains("QXcbConnection: XCB error:"))) {
+        return;
+    }
+
 #ifndef INTEGRATION_TESTS
     // log to the log file
     logToFileIfAllowed(logType, text);
@@ -326,7 +348,17 @@ void LogWidget::logMessageOutput(
             logType = LogType::FatalLogType;
     }
 
-    LogWidget::instance()->log(logType, msg);
+#ifndef INTEGRATION_TESTS
+    MainWindow *mainWindow = MainWindow::instance();
+
+    if (mainWindow != Q_NULLPTR) {
+        // handle logging as signal/slot to even more prevent crashes when
+        // writing to the log-widget while the app is shutting down
+        emit(mainWindow->log(logType, msg));
+    }
+#else
+    Q_UNUSED(logType);
+#endif
 
     // it's harder to debug a problem if we abort here
 //    if (type == QtFatalMsg) {
@@ -410,3 +442,26 @@ void LogWidget::onDestroyed(QObject *obj) {
     qApp->setProperty("loggingEnabled", false);
 #endif
 }
+
+/**
+ * Event filters
+ *
+ * @param obj
+ * @param event
+ * @return
+ */
+bool LogWidget::eventFilter(QObject *obj, QEvent *event) {
+    if (event->type() == QEvent::KeyPress) {
+        QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
+
+        // hide the option frame on Escape key
+        if (keyEvent->key() == Qt::Key_Escape) {
+#ifndef INTEGRATION_TESTS
+            ui->buttonFrame->hide();
+#endif
+            return false;
+        }
+    }
+
+    return QFrame::eventFilter(obj, event);
+}
