@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2017 Patrizio Bekerle -- http://www.bekerle.com
+ * Copyright (c) 2014-2019 Patrizio Bekerle -- http://www.bekerle.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,8 @@ public:
     void initSearchFrame(QWidget *searchFrame, bool darkMode = false);
     QTextEditSearchWidget *searchWidget();
 
+    void setHtml(const QString &text);
+
 protected:
     QTextEditSearchWidget *_searchWidget;
     QWidget *_searchFrame;
@@ -33,6 +35,9 @@ protected:
     void resizeEvent(QResizeEvent* event);
     bool eventFilter(QObject *obj, QEvent *event);
 
+    QStringList extractGifUrls(const QString &text) const;
+    void animateGif(const QString &text);
+
 public slots:
     void hide();
 
@@ -40,4 +45,5 @@ signals:
     void resize(QSize size, QSize oldSize);
 
 private:
+    QList<QMovie*> _movies;
 };
