@@ -2,6 +2,7 @@
 #define QOWNNOTESMARKDOWNTEXTEDIT_H
 
 #include <QObject>
+#include <helpers/qownnotesmarkdownhighlighter.h>
 #include "libraries/qmarkdowntextedit/qmarkdowntextedit.h"
 #include "mainwindow.h"
 
@@ -33,9 +34,14 @@ public:
     void setMainWindow(MainWindow *mainWindow);
     int modifyFontSize(FontModificationMode mode);
     void updateSettings();
+    QMargins viewportMargins();
 
 protected:
+    // we must not override _highlighter or Windows will create a QOwnNotesMarkdownHighlighter and MarkdownHighlighter instance
+//    QOwnNotesMarkdownHighlighter *_highlighter;
     void insertFromMimeData(const QMimeData * source);
+    void resizeEvent(QResizeEvent* event);
+    bool eventFilter(QObject *obj, QEvent *event);
 
 private slots:
     void highlightCurrentLine();
@@ -44,6 +50,9 @@ private:
     MainWindow *mainWindow;
 
     void setFormatStyle(MarkdownHighlighter::HighlighterState index);
+
+Q_SIGNALS:
+    void resize(QResizeEvent* event);
 };
 
 #endif // QOWNNOTESMARKDOWNTEXTEDIT_H
